package com.crm.manager.service.ib;

import com.crm.rely.backend.core.dto.base.BaseResultDto;
import com.crm.rely.backend.core.dto.base.BaseResultWithPagerDto;
import com.crm.rely.backend.core.dto.mam.MamLeverageApplyDto;
import com.crm.rely.backend.core.dto.mam.MamPwdResetDto;
import com.crm.rely.backend.core.dto.mam.MamRepwdDto;
import com.crm.rely.backend.core.entity.mam.*;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;

import java.util.List;

/**
 * Created by max on 2020/8/24.
 */
@FeignClient(value = "IB-SERVICE", path = "/manage/service/mam")
public interface MamSettingFeignService {


    @PostMapping("/repwd/list")
    BaseResultWithPagerDto<List<MamRepwdDto>> mamRepwdList(MamRepwdListEntity entity) throws Exception;

    @PostMapping("/repwd/approve")
    BaseResultDto<Object> mamRepwdApprove(MamRepwdApproveEntity entity) throws Exception;

    @PostMapping("/pwd/reset/list")
    BaseResultWithPagerDto<List<MamPwdResetDto>> mamPwdResetList(MamPwdResetListEntity entity) throws Exception;

    @PostMapping("/pwd/reset/approve")
    BaseResultDto<Object> mamPwdResetApprove(MamPwdResetApproveEntity entity) throws Exception;

    @PostMapping("/leverage/apply/list")
    BaseResultWithPagerDto<List<MamLeverageApplyDto>> mamLeverageApplyList(MamLeverageApplyListEntity entity) throws Exception;

    @PostMapping("/leverage/apply/approve")
    BaseResultDto<Object> mamLeverageApplyApprove(MamLeverageApplyApproveEntity entity) throws Exception;

}
